@@ -48,23 +48,6 @@ const gchar *GKBD_KEYBOARD_CONFIG_ACTIVE[] = {
 	GKBD_KEYBOARD_CONFIG_KEY_OPTIONS
 };
 
-#define GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_PREFIX GKBD_CONFIG_KEY_PREFIX "/kbd.sysbackup"
-
-const gchar GKBD_KEYBOARD_CONFIG_SYSBACKUP_DIR[] =
-    GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_PREFIX;
-const gchar GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_MODEL[] =
-    GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_PREFIX "/model";
-const gchar GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_LAYOUTS[] =
-    GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_PREFIX "/layouts";
-const gchar GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_OPTIONS[] =
-    GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_PREFIX "/options";
-
-const gchar *GKBD_KEYBOARD_CONFIG_SYSBACKUP[] = {
-	GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_MODEL,
-	GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_LAYOUTS,
-	GKBD_KEYBOARD_CONFIG_SYSBACKUP_KEY_OPTIONS
-};
-
 /**
  * static common functions
  */
@@ -342,7 +325,7 @@ gkbd_keyboard_config_load_params (GkbdKeyboardConfig * kbd_config,
 {
 	GError *gerror = NULL;
 	gchar *pc;
-	GSList *pl;
+	GSList *pl, *l;
 
 	pc = gconf_client_get_string (kbd_config->conf_client,
 				      param_names[0], &gerror);
@@ -364,7 +347,7 @@ gkbd_keyboard_config_load_params (GkbdKeyboardConfig * kbd_config,
 
 	gkbd_keyboard_config_layouts_reset (kbd_config);
 
-	pl = gconf_client_get_list (kbd_config->conf_client,
+	l = pl = gconf_client_get_list (kbd_config->conf_client,
 				    param_names[1],
 				    GCONF_VALUE_STRING, &gerror);
 	if (pl == NULL || gerror != NULL) {
@@ -376,17 +359,17 @@ gkbd_keyboard_config_load_params (GkbdKeyboardConfig * kbd_config,
 		}
 	}
 
-	while (pl != NULL) {
-		xkl_debug (150, "Loaded Kbd layout: [%s]\n", pl->data);
+	while (l != NULL) {
+		xkl_debug (150, "Loaded Kbd layout: [%s]\n", l->data);
 		gkbd_keyboard_config_layouts_add_full (kbd_config,
-						       pl->data);
-		pl = pl->next;
+						       l->data);
+		l = l->next;
 	}
 	gkbd_keyboard_config_string_list_reset (&pl);
 
 	gkbd_keyboard_config_options_reset (kbd_config);
 
-	pl = gconf_client_get_list (kbd_config->conf_client,
+	l = pl = gconf_client_get_list (kbd_config->conf_client,
 				    param_names[2],
 				    GCONF_VALUE_STRING, &gerror);
 	if (pl == NULL || gerror != NULL) {
@@ -398,12 +381,12 @@ gkbd_keyboard_config_load_params (GkbdKeyboardConfig * kbd_config,
 		}
 	}
 
-	while (pl != NULL) {
-		xkl_debug (150, "Loaded Kbd option: [%s]\n", pl->data);
+	while (l != NULL) {
+		xkl_debug (150, "Loaded Kbd option: [%s]\n", l->data);
 		gkbd_keyboard_config_options_add_full (kbd_config,
-						       (const gchar *) pl->
+						       (const gchar *) l->
 						       data);
-		pl = pl->next;
+		l = l->next;
 	}
 	gkbd_keyboard_config_string_list_reset (&pl);
 }
@@ -486,6 +469,7 @@ gkbd_keyboard_config_term (GkbdKeyboardConfig * kbd_config)
 	gkbd_keyboard_config_model_set (kbd_config, NULL);
 
 	gkbd_keyboard_config_layouts_reset (kbd_config);
+	gkbd_keyboard_config_options_reset (kbd_config);
 
 	g_object_unref (kbd_config->conf_client);
 	kbd_config->conf_client = NULL;
@@ -529,14 +513,6 @@ gkbd_keyboard_config_load_from_gconf (GkbdKeyboardConfig * kbd_config,
 	}
 }
 
-void
-gkbd_keyboard_config_load_from_gconf_backup (GkbdKeyboardConfig *
-					     kbd_config)
-{
-	gkbd_keyboard_config_load_params (kbd_config,
-					  GKBD_KEYBOARD_CONFIG_SYSBACKUP);
-}
-
 void
 gkbd_keyboard_config_load_from_x_current (GkbdKeyboardConfig * kbd_config,
 					  XklConfigRec * data)
@@ -612,28 +588,6 @@ gkbd_keyboard_config_save_to_gconf (GkbdKeyboardConfig * kbd_config)
 	gconf_change_set_unref (cs);
 }
 
-void
-gkbd_keyboard_config_save_to_gconf_backup (GkbdKeyboardConfig * kbd_config)
-{
-	GConfChangeSet *cs;
-	GError *gerror = NULL;
-
-	cs = gconf_change_set_new ();
-
-	gkbd_keyboard_config_save_params (kbd_config, cs,
-					  GKBD_KEYBOARD_CONFIG_SYSBACKUP);
-
-	gconf_client_commit_change_set (kbd_config->conf_client, cs, TRUE,
-					&gerror);
-	if (gerror != NULL) {
-		g_warning ("Error saving backup configuration: %s\n",
-			   gerror->message);
-		g_error_free (gerror);
-		gerror = NULL;
-	}
-	gconf_change_set_unref (cs);
-}
-
 void
 gkbd_keyboard_config_model_set (GkbdKeyboardConfig * kbd_config,
 				const gchar * model_name)
@@ -793,8 +747,10 @@ gkbd_keyboard_config_to_string (const GkbdKeyboardConfig * config)
 
 		/* Translators: The count is related to the number of options. The %s
 		 * format specifier should not be modified, left "as is". */
-		layouts = g_strdup_printf (ngettext ("layout \"%s\"", "layouts \"%s\"",
-					count), buffer->str);
+		layouts =
+		    g_strdup_printf (ngettext
+				     ("layout \"%s\"", "layouts \"%s\"",
+				      count), buffer->str);
 		g_string_truncate (buffer, 0);
 	}
 	if (config->options) {
@@ -810,8 +766,10 @@ gkbd_keyboard_config_to_string (const GkbdKeyboardConfig * config)
 
 		/* Translators: The count is related to the number of options. The %s
 		 * format specifier should not be modified, left "as is". */
-		options = g_strdup_printf (ngettext ("option \"%s\"", "options \"%s\"",
-					count), buffer->str);
+		options =
+		    g_strdup_printf (ngettext
+				     ("option \"%s\"", "options \"%s\"",
+				      count), buffer->str);
 		g_string_truncate (buffer, 0);
 	}
 
